@@ -18,7 +18,7 @@ class Hentai2read(object):
         api_key : str
             scathach.dev API key (optional)
         """
-        if api_key is '':
+        if api_key == '':
             self.api_key = None
         else:
             self.api_key = api_key
@@ -48,9 +48,13 @@ class Hentai2read(object):
             The book object that represents the specific id response.
         """
 
-        path = path.replace('/', '')
+        ## if path contains '/' then remove it
+        if '/' in path:
+            path = path.replace('/', '')
+        
         self.specs['u'] = path + '/' + str(chapter)
 
+
         try:
             path = str(path)
         except ValueError:
