@@ -18,7 +18,7 @@ class Hentaifox(object):
         api_key : str
             scathach.dev API key (optional)
         """
-        if api_key is '':
+        if api_key == '':
             self.api_key = None
         else:
             self.api_key = api_key
